﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;
using Infragistics.Windows.DataPresenter;
using Infragistics.Windows.DataPresenter.Events;
using System.ComponentModel;

namespace xamDataGrid1
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        public MainWindow()
        {
            InitializeComponent();
            Loaded += MainWindow_Loaded;
        }

        private void MainWindow_Loaded(object sender, RoutedEventArgs e)
        {
            daGrid.FieldLayoutInitialized += daGrid_FieldLayoutInitialized;
            daGrid.DataSource = RiskCollection.GetRiskCollection();
        }

        private void daGrid_FieldLayoutInitialized(object sender, FieldLayoutInitializedEventArgs e)
        {
            var fieldLayout = e.FieldLayout;
            fieldLayout.Settings.HeaderPlacementInGroupBy = HeaderPlacementInGroupBy.OnTopOnly;
            fieldLayout.Settings.HeaderPlacement = HeaderPlacement.OnTopOnly;
            fieldLayout.Settings.GroupBySummaryDisplayMode = GroupBySummaryDisplayMode.SummaryCellsAlwaysBelowDescription;
            //fieldLayout.FieldSettings.SortComparer = new GroupByComparer();
            //fieldLayout.FieldSettings.GroupByComparer = new GroupByComparer();
            FieldSortDescription fieldSortDescription = new FieldSortDescription("Asset", System.ComponentModel.ListSortDirection.Ascending, true);
            fieldLayout.SortedFields.Add(fieldSortDescription);
            fieldLayout.FieldSettings.SummaryDisplayArea = SummaryDisplayAreas.InGroupByRecords | SummaryDisplayAreas.Bottom;
            this.applyRowSummaries(fieldLayout);
        }
        private void applyRowSummaries(FieldLayout layout)
        {
            SummaryDefinition def = layout.SummaryDefinitions.Add("Gamma", SummaryCalculator.Sum, "Gamma");
            def.StringFormat = "{0:C}";
            def = layout.SummaryDefinitions.Add("Theta", SummaryCalculator.Sum, "Theta");
            def.StringFormat = "{0:C}";
            def = layout.SummaryDefinitions.Add("Vol", SummaryCalculator.Sum, "Vol");
            def.StringFormat = "{0:C}";
            layout.Settings.SummaryDescriptionVisibility = Visibility.Collapsed;
        }

        private void daGrid_Sorting(object sender, SortingEventArgs e)
        {
            foreach (SummaryDefinition summaryDefinition in e.FieldLayout.SummaryDefinitions)
            {
                if (summaryDefinition.Key == e.SortDescription.FieldName)
                {
                    if (e.SortDescription.Direction == ListSortDirection.Ascending)
                    {
                        e.FieldLayout.FieldSettings.GroupByComparer = new GroupByComparer(e.SortDescription.FieldName, true);
                    }
                    else
                    {
                        e.FieldLayout.FieldSettings.GroupByComparer = new GroupByComparer(e.SortDescription.FieldName, false);
                    }
                    return;
                }
            }
        }
    }
}
